# Command Line Interface

The `abqcy` command line is used to compile you Cython code into an object (`.obj`) file that can be used by Abaqus.

## References

### The `abqcy` command

```{command-output} abqcy
```

### The `abqcy compile` command

```{command-output} abqcy compile --help
```

### The `abqcy run` command

```{command-output} abqcy run --help
:returncode: 2
```
